summaryrefslogtreecommitdiffstats
path: root/src/modules/clock
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 18:31:12 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-28 18:31:12 +0000
commit0a80cfd57d271dd44221467efb426675fa470356 (patch)
tree6f503a31aa078eaf8fa015cf1749808529d49fc9 /src/modules/clock
parent3329e5a804e28ef3f5eb51d1e7affdd5a508e8f2 (diff)
downloadkvirc-0a80cfd57d271dd44221467efb426675fa470356.tar.gz
kvirc-0a80cfd57d271dd44221467efb426675fa470356.zip
TQt4 port kvirc
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/kvirc@1238719 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/modules/clock')
-rw-r--r--src/modules/clock/libkviclock.cpp28
-rw-r--r--src/modules/clock/libkviclock.h7
2 files changed, 18 insertions, 17 deletions
diff --git a/src/modules/clock/libkviclock.h b/src/modules/clock/libkviclock.h
index bf4881a..7c960df 100644
--- a/src/modules/clock/libkviclock.h
+++ b/src/modules/clock/libkviclock.h
@@ -30,15 +30,16 @@
class KviClockDisplay : public KviIrcToolBarGraphicalApplet
{
Q_OBJECT
+ TQ_OBJECT
public:
KviClockDisplay(KviIrcToolBarAppletContainer * pContainer);
~KviClockDisplay();
protected:
unsigned char m_uDigit[6];
protected:
- virtual void drawContents(QPainter * p);
- virtual QSize sizeHint() const;
- virtual void timerEvent(QTimerEvent *e);
+ virtual void drawContents(TQPainter * p);
+ virtual TQSize tqsizeHint() const;
+ virtual void timerEvent(TQTimerEvent *e);
};
#endif
diff --git a/src/modules/clock/libkviclock.cpp b/src/modules/clock/libkviclock.cpp
index 03757b0..1b73121 100644
--- a/src/modules/clock/libkviclock.cpp
+++ b/src/modules/clock/libkviclock.cpp
@@ -29,9 +29,9 @@
#include "kvi_locale.h"
#include "kvi_pointerlist.h"
-#include <qbitmap.h>
-#include <qtooltip.h>
-#include <qpainter.h>
+#include <tqbitmap.h>
+#include <tqtooltip.h>
+#include <tqpainter.h>
@@ -42,7 +42,7 @@
#if 0
#warning "Change this XPM to bitmap bits! (And thus use the QBitmap(w,h,bits) constructor)"
#warning "Support GMT , LOCAL , DATE , ALARM..."
/* XPM */
@@ -81,13 +81,13 @@ static const char * kvi_clock_digits_xpm[] = {
// kvi_app.cpp
//extern Display * g_display;
//extern GC g_iccGC;
-extern QPixmap * g_pIccMemBuffer;
+extern TQPixmap * g_pIccMemBuffer;
//extern HANDLE g_hIccMemBuffer;
static KviPointerList<KviClockDisplay> * g_pClockWidgetList;
-static QBitmap * g_pClockBitmap = 0;
+static TQBitmap * g_pClockBitmap = 0;
KviClockDisplay::KviClockDisplay(KviIrcToolBarAppletContainer * pContainer)
@@ -108,7 +108,7 @@ KviClockDisplay::~KviClockDisplay()
g_pClockWidgetList->removeRef(this);
}
-void KviClockDisplay::timerEvent(QTimerEvent *e)
+void KviClockDisplay::timerEvent(TQTimerEvent *e)
{
time_t t = time(0);
struct tm * pTm = gmtime(&t);
@@ -125,7 +125,7 @@ void KviClockDisplay::timerEvent(QTimerEvent *e)
-void KviClockDisplay::drawContents(QPainter *p)
+void KviClockDisplay::drawContents(TQPainter *p)
{
//XSetLineAttributes(g_display,g_iccGC,1,LineSolid,CapButt,JoinMiter); //need this for line size
@@ -144,7 +144,7 @@ void KviClockDisplay::drawContents(QPainter *p)
p->setBrushOrigin(- 180 + _x,LOW_ROW_Y); \
p->fillRect(_x,LOW_ROW_Y,9,18,_br);
- QBrush br1(KVI_OPTION_COLOR(KviOption_colorIrcToolBarAppletForegroundLowContrast),*g_pClockBitmap);
+ TQBrush br1(KVI_OPTION_COLOR(KviOption_colorIrcToolBarAppletForegroundLowContrast),*g_pClockBitmap);
p->setBrushOrigin(- 216,LOW_ROW_Y);
p->fillRect(0,LOW_ROW_Y,18,18,br1);
@@ -152,7 +152,7 @@ void KviClockDisplay::drawContents(QPainter *p)
p->setBrushOrigin(22,LOW_ROW_Y + 2 /*-18 + LOW_ROW_Y + 20 */);
p->fillRect(22,LOW_ROW_Y + 20,18 * 5,7,br1);
- QBrush br2(KVI_OPTION_COLOR(KviOption_colorIrcToolBarAppletForegroundHighContrastActive1),*g_pClockBitmap);
+ TQBrush br2(KVI_OPTION_COLOR(KviOption_colorIrcToolBarAppletForegroundHighContrastActive1),*g_pClockBitmap);
DRAW_DIGIT(22,0,br2)
DRAW_DIGIT(40,1,br2)
@@ -169,9 +169,9 @@ void KviClockDisplay::drawContents(QPainter *p)
}
-QSize KviClockDisplay::sizeHint() const
+TQSize KviClockDisplay::tqsizeHint() const
{
- return QSize(KVI_IRCTOOLBARAPPLET_MAXIMUM_WIDTH,KVI_IRCTOOLBARAPPLET_MAXIMUM_HEIGHT);
+ return TQSize(KVI_IRCTOOLBARAPPLET_MAXIMUM_WIDTH,KVI_IRCTOOLBARAPPLET_MAXIMUM_HEIGHT);
}
@@ -209,8 +209,8 @@ static bool clock_module_cmd_add(KviModule *m,KviCommand *c)
static bool clock_module_init(KviModule *m)
{
#if 0
- g_pClockBitmap = new QBitmap();
- QPixmap pix(kvi_clock_digits_xpm);
+ g_pClockBitmap = new TQBitmap();
+ TQPixmap pix(kvi_clock_digits_xpm);
*g_pClockBitmap = pix;
g_pClockWidgetList = new KviPointerList<KviClockDisplay>;
g_pClockWidgetList->setAutoDelete(false);
@@ -42,7 +42,7 @@
#if 0
-#warning "Change this XPM to bitmap bits! (And thus use the QBitmap(w,h,bits) constructor)"
+#warning "Change this XPM to bitmap bits! (And thus use the TQBitmap(w,h,bits) constructor)"
#warning "Support GMT , LOCAL , DATE , ALARM..."
/* XPM */